@@ -23,14 +23,13 @@ following metadata in the autobuild.xml file:
 import getpass
 import glob
 import hashlib
-import io
+import json
 import logging
 import os
 import re
 import subprocess
 import tarfile
-import urllib.parse
-import urllib.request
+from collections import UserDict
 from zipfile import ZIP_DEFLATED, ZipFile
 
 from autobuild import autobuild_base, common, configfile
@@ -128,6 +127,18 @@ class PackageError(AutobuildError):
     pass
 
 
+class PackageResults(UserDict):
+    """Package information result file, formatted as JSON or shell-sourceable k=v lines"""
+    def write(self, filename):
+        if os.path.splitext(filename)[1] == ".json":
+            with open(filename, "w") as f:
+                json.dump(self.data, f)
+        else:
+            with open(filename, "w", newline="\n") as f:
+                for k, v in self.items():
+                    f.write(f'{k}="{v}"\n')
+
+
 def package(config, build_directory, platform_name, archive_filename=None, archive_format=None, clean_only=False, results_file=None, dry_run=False):
     """
     Create an archive for the given platform.
@@ -200,18 +211,13 @@ def package(config, build_directory, platform_name, archive_filename=None, archi
     # (they use the --results-file option instead)
     print("packing %s" % package_description.name)
 
-    results = None
+    results = PackageResults({
+        'autobuild_package_name': package_description.name,
+        'autobuild_package_clean': 'false' if metadata_file.dirty else 'true',
+        'autobuild_package_metadata': metadata_file_path,
+        'autobuild_package_platform': metadata_file.platform,
+    })
     if not dry_run:
-        if results_file:
-            try:
-                # Do not write carriage returns
-                results=io.open(results_file, 'w', newline="\n")
-            except IOError as err:
-                raise PackageError("Unable to open results file %s:\n%s" % (results_file, err))
-            results.write('autobuild_package_name="%s"\n' % package_description.name)
-            results.write('autobuild_package_clean="%s"\n' % ("false" if metadata_file.dirty else "true"))
-            results.write('autobuild_package_metadata="%s"\n' % metadata_file_path)
-            results.write('autobuild_package_platform="%s"\n' % metadata_file.platform)
         metadata_file.save()
 
     # add the metadata file name to the list of files _after_ putting that list in the metadata
@@ -239,10 +245,11 @@ def package(config, build_directory, platform_name, archive_filename=None, archi
             _create_zip_archive(tarfilename + '.zip', build_directory, files, results)
         else:
             raise PackageError("archive format %s is not supported" % format)
-    if not dry_run and results:
-        results.close()
+    if not dry_run and results_file:
+        results.write(results_file)
     return not metadata_file.dirty
 
+
 def _determine_archive_format(archive_format_argument, archive_description):
     if archive_format_argument is not None:
         return archive_format_argument
@@ -281,7 +288,7 @@ def _get_file_list(platform_description, build_directory):
             os.chdir(current_directory)
     return [files, missing]
 
-def _create_tarfile(tarfilename, build_directory, filelist, results):
+def _create_tarfile(tarfilename, build_directory, filelist, results: dict):
     if not os.path.exists(os.path.dirname(tarfilename)):
         os.makedirs(os.path.dirname(tarfilename))
     current_directory = os.getcwd()
@@ -312,12 +319,11 @@ def _create_tarfile(tarfilename, build_directory, filelist, results):
     # the Linden Lab build scripts no longer rely on this
     # (they use the --results-file option instead)
     print("wrote  %s" % tarfilename)
-    if results:
-        results.write('autobuild_package_filename="%s"\n' % tarfilename)
+    results['autobuild_package_filename'] = tarfilename
     _print_hash(tarfilename, results)
 
 
-def _create_zip_archive(archive_filename, build_directory, file_list, results):
+def _create_zip_archive(archive_filename, build_directory, file_list, results: dict):
     if not os.path.exists(os.path.dirname(archive_filename)):
         os.makedirs(os.path.dirname(archive_filename))
     current_directory = os.getcwd()
@@ -334,8 +340,7 @@ def _create_zip_archive(archive_filename, build_directory, file_list, results):
     # the Linden Lab build scripts no longer rely on this
     # (they use the --results-file option instead)
     print("wrote  %s" % archive_filename)
-    if results:
-        results.write('autobuild_package_filename="%s"\n' % archive_filename)
+    results['autobuild_package_filename'] = archive_filename
     _print_hash(archive_filename, results)
 
 
@@ -360,7 +365,7 @@ def _add_file_to_zip_archive(zip_file, unnormalized_file, archive_filename, adde
         logger.info('added ' + file)
 
 
-def _print_hash(filename, results):
+def _print_hash(filename: str, results: dict):
     fp = open(filename, 'rb')
     m = hashlib.md5()
     while True:
@@ -372,9 +377,7 @@ def _print_hash(filename, results):
     # the Linden Lab build scripts no longer rely on this
     # (they use the --results-file option instead)
     print("md5    %s" % m.hexdigest())
-    if results:
-        results.write('autobuild_package_md5="%s"\n' % m.hexdigest())
-
+    results['autobuild_package_md5'] = m.hexdigest()
     # Not using logging, since this output should be produced unconditionally on stdout
     # Downstream build tools utilize this output
 
